CoordinateSystem: Coordinate system

CoordinateSystemR Documentation

Coordinate system

Description

This class implements the coordinate system class. This class definition implements the same class from the OGC geoAPI Java package, extended with specific code for this package.

Super classes

zarr::zarr_object -> IdentifiedObject -> CoordinateSystem

Active bindings

axes

(read-only) Retrieve the list of axes that make up this coordinate system.

crs

Set or retreive the CRS identifier of the coordinate system.

Methods

Public methods

Inherited methods

CoordinateSystem$new()

Create a new coordinate system. The CS must have at least one axis.

Usage
CoordinateSystem$new(name, axes, crs = "", attributes = list())
Arguments
name

Character string. Name of the coordinate system.

axes

A list of instances of CoordinateSystemAxis. There must be at least one axis in the list.

crs

Optional, character string with the description of the CRS of this coordinate system, always assumed to be compound.

attributes

Optional. A list of attributes of the coordinate system.

Returns

An instance of CoordinateSystem or an error.


CoordinateSystem$print()

Print a summary of the coordinate system to the console.

Usage
CoordinateSystem$print(...)
Arguments
...

Ignored.

Returns

Self, invisibly.


CoordinateSystem$print_axes()

Prints details of the axes of the coordinate system to the console. Used internally.

Usage
CoordinateSystem$print_axes(...)
Arguments
...

Arguments passed on to data.frame printing.


CoordinateSystem$getDimension()

Retrieve the dimension of the coordinate system, the number of axes that make up the coordinate system.

Usage
CoordinateSystem$getDimension()
Returns

Integer value with the dimension of the coordinate system.


CoordinateSystem$getAxis()

Retrieve an axis of the coordinate system by its ordinal number.

Usage
CoordinateSystem$getAxis(dimension)
Arguments
dimension

The dimension whose axis to retrieve. Note that this is 1-based.

Returns

The CoordinateSystemAxis that forms the dimension of the coordinate system, or an error if the dimension argument in deficient.


CoordinateSystem$clone()

The objects of this class are cloneable with this method.

Usage
CoordinateSystem$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.