CoordinateSystemAxis: Coordinate system axis

CoordinateSystemAxisR Documentation

Coordinate system axis

Description

This class implements the coordinate system axis class. The axis is always associated with a coordinate system.

In an extension over the OGC standard, an axis can have multiple sets of coordinates. The unit-of-measure is associated with the coordinates and thus not with the axis.

Super classes

zarr::zarr_object -> IdentifiedObject -> CoordinateSystemAxis

Active bindings

abbreviation

Set or retrieve the abbreviation of the axis.

coordinates_list

(read-only) Retrieve all coordinates in a list.

coordinates

(read-only) Retrieve the currently active coordinates.

length

(read-only) Retrieve the length of the axis.

Methods

Public methods

Inherited methods

CoordinateSystemAxis$new()

Create a new axis instance for use in a coordinate system.

Usage
CoordinateSystemAxis$new(name, abbreviation, coordinates, attributes = list())
Arguments
name

Character string. Name of the axis.

abbreviation

Character string. Abbreviation of the axis.

coordinates

A list with one or more named instances of the Coordinates class, or any of its descendants. The first element in the list will be made active.

attributes

Optional. A list of attributes of the axis.

Returns

An instance of this class or an error.


CoordinateSystemAxis$print()

Print a summary of the coordinate system axis to the console.

Usage
CoordinateSystemAxis$print(...)
Arguments
...

Ignored.

Returns

Self, invisible.


CoordinateSystemAxis$brief()

Some details of the axis.

Usage
CoordinateSystemAxis$brief()
Returns

A 1-row data.frame with some details of the axis.


CoordinateSystemAxis$copy()

Return an exact copy of this axis.

Usage
CoordinateSystemAxis$copy()
Returns

A new instance of CoordinateSystemAxis.


CoordinateSystemAxis$subset()

Return an axis spanning a smaller coordinate range. This method returns an axis which spans the range of indices given by the rng argument.

Usage
CoordinateSystemAxis$subset(name = "", rng = NULL)
Arguments
name

The name for the new axis. If an empty string is passed (default), will use the name of this axis.

rng

The range of indices whose values from this axis to include in the returned axis. If the value of the argument is NULL, return a copy of the axis.

Returns

A new CoordinateSystemAxis instance covering the indicated range of indices. If the value of the argument rng is NULL, return a copy of this axis as the new axis.


CoordinateSystemAxis$slice()

Given a range of domain coordinate values, returns the indices into this axis that fall within the supplied range. If the axis has bounds, any coordinate whose boundary values fall entirely or partially within the supplied range will be included in the result.

Usage
CoordinateSystemAxis$slice(rng)
Arguments
rng

A numeric vector whose extreme values indicate the indices of coordinates to return.

Returns

An integer vector of length 2 with the lower and higher indices into the axis that fall within the range of coordinates in argument rng. Returns NULL if no (boundary) values of the axis fall within the range of coordinates.


CoordinateSystemAxis$getAbbreviation()

Retrieve the abbreviation of the axis. This method is mandatory in the OGC standard.

Usage
CoordinateSystemAxis$getAbbreviation()
Returns

Character string with the abbreviation of the axis.


CoordinateSystemAxis$getDirection()

Retrieve the direction of the axis. This method is mandatory in the OGC standard.

Usage
CoordinateSystemAxis$getDirection()
Returns

Character string with the direction of the axis.


CoordinateSystemAxis$getUnit()

Retrieve the unit of measure of the axis. This method is mandatory in the OGC standard.

Usage
CoordinateSystemAxis$getUnit()
Returns

Character string with the unit of measure of the axis.


CoordinateSystemAxis$getMinimumValue()

Retrieve the minimum coordinate value of this axis, in units of the unit of measure of the axis.

Usage
CoordinateSystemAxis$getMinimumValue()
Returns

Negative infinity.


CoordinateSystemAxis$getMaximumValue()

Retrieve the maximum coordinate value of this axis, in units of the unit of measure of the axis.

Usage
CoordinateSystemAxis$getMaximumValue()
Returns

Positive infinity.


CoordinateSystemAxis$getRangeMeaning()

Retrieve the minimum coordinate value of this axis, in units of the unit of measure of the axis.

Usage
CoordinateSystemAxis$getRangeMeaning()
Returns

The character string 'EXACT'.


CoordinateSystemAxis$clone()

The objects of this class are cloneable with this method.

Usage
CoordinateSystemAxis$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.