CoordinatesOrdinal: Ordinal coordinate values

CoordinatesOrdinalR Documentation

Ordinal coordinate values

Description

This class implements ordinal values. Ordinal values are typically assigned to axes that have no other coordinates assigned to them. By default, ordinal values start at 0 (as per the Zarr specification) but after subsetting or other forms of selection the value may be different.

Super classes

zarr::zarr_object -> Coordinates -> CoordinatesPacked -> CoordinatesOrdinal

Methods

Public methods

Inherited methods

CoordinatesOrdinal$new()

Create an instance of this class.

Usage
CoordinatesOrdinal$new(name, direction, length, low = 0L, attributes = list())
Arguments
name

Character string. Name of the coordinate set.

direction

Character string. Direction of the coordinates. Must be one from a set of values.

length

Integer value giving the number of elements in this instance.

low

Optional. Integer value giving the lowest index value in this instance. When omitted, defaults to 0L.

attributes

Optional. A list of attributes of the coordinates.

Returns

An instance of this class.


CoordinatesOrdinal$copy()

Return an exact copy of these coordinates.

Usage
CoordinatesOrdinal$copy()
Returns

A new instance of CoordinatesOrdinal.


CoordinatesOrdinal$subset()

Return a subset of the coordinate values.

Usage
CoordinatesOrdinal$subset(rng)
Arguments
rng

The range of indices whose values from these coordinate values to include in the result.

Returns

A new CoordinatesOrdinal instance covering the indicated range of values.


CoordinatesOrdinal$clone()

The objects of this class are cloneable with this method.

Usage
CoordinatesOrdinal$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.