CoordinatesPacked: Packed coordinates

CoordinatesPackedR Documentation

Packed coordinates

Description

This class implements the packed coordinates class. The coordinates are always associated with a coordinate system axis.

This class provides the specific interface for packed numeric coordinate values, both integer and floating-point.

Super classes

zarr::zarr_object -> Coordinates -> CoordinatesPacked

Active bindings

values

(read-only) Retrieve the unpacked coordinate values.

range

(read-only) Retrieve the extreme values of the coordinates.

Methods

Public methods

Inherited methods

CoordinatesPacked$new()

Create a new coordinates instance for use with a coordinate system axis for regularly spaced coordinate values.

Usage
CoordinatesPacked$new(
  name,
  direction,
  unit,
  values,
  length,
  bounds = NULL,
  attributes = list()
)
Arguments
name

Character string. Name of the coordinate set.

direction

Character string. Direction of the coordinates. Must be one from a set of values.

unit

Character string. Unit of measure of the coordinates.

values

A vector of values. There must be two values: the initial coordinate value and the increment.

length

Integer value giving the number of coordinates that this packed data is for.

bounds

Optional. If the boundaries are regularly spaced, a vector with the offset to the boundary lower and higher than the coordinate value, respectively. Otherwise, a matrix with two rows and as many columns as there are elements, with the offset to the boundary below the coordinate value in row 1 and the offset to the boundary above the coordinate value in row 2. The boundaries represent the finite extent around the boundary value that this value is representative for. If this argument is not provided, the coordinate values are assumed to represent a point value.

attributes

Optional. A list of attributes of the coordinates.

Returns

An instance of this class or an error.


CoordinatesPacked$copy()

Return an exact copy of these coordinates.

Usage
CoordinatesPacked$copy()
Returns

A new instance of CoordinatesPacked.


CoordinatesPacked$subset()

Return coordinates spanning a smaller coordinate range.

Usage
CoordinatesPacked$subset(rng)
Arguments
rng

The range of indices to include in the returned coordinates.

Returns

A new CoordinatesPacked instance covering the indicated range of indices, including boundary values, present.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.