CoordinatesString: String-type coordinates

CoordinatesStringR Documentation

String-type coordinates

Description

This class implements the string-type coordinates class. The coordinates are always associated with a coordinate system axis.

This class provides the specific interface for string-type coordinate values.

Super classes

zarr::zarr_object -> Coordinates -> CoordinatesString

Methods

Public methods

Inherited methods

CoordinatesString$new()

Create a new coordinates instance for use with a coordinate system axis for string-type coordinate values.

Usage
CoordinatesString$new(name, direction, unit, values, attributes = list())
Arguments
name

Character string. Name of the coordinate set.

direction

Character string. Direction of the coordinates. Must be one from a set of values.

unit

Character string. Unit of measure of the coordinates.

values

A vector of values. There must be two values: the initial coordinate value and the increment.

attributes

Optional. A list of attributes of the coordinates.

Returns

An instance of this class or an error.


CoordinatesString$copy()

Return an exact copy of these coordinates.

Usage
CoordinatesString$copy()
Returns

A new instance of CoordinatesString.


CoordinatesString$subset()

Return coordinates spanning a smaller coordinate range.

Usage
CoordinatesString$subset(rng)
Arguments
rng

The range of indices to include in the returned coordinates.

Returns

A new CoordinatesString instance covering the indicated range of indices.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.