IdentifiedObject: Identified object

IdentifiedObjectR Documentation

Identified object

Description

This class definition implements the same class from the OGC geoAPI Java package, extended with specific code for this package. This class is ancestor to many other, more useful classes. This class just provides basic identification properties. It is not very useful to instantiate this class directly; instead, use descendant classes.

Super class

zarr::zarr_object -> IdentifiedObject

Active bindings

name

(read-only) The name of the object.

attributes

(read-only) A named list with the attributes of this object.

Methods

Public methods

Inherited methods

IdentifiedObject$new()

Create a new object.

Usage
IdentifiedObject$new(name, attributes = list())
Arguments
name

Character string. Name of the object.

attributes

Optional. A list of attributes of the object.

Returns

A new instance of the object, or an error if the object could not be created.


IdentifiedObject$getName()

Retrieve the name of the object. This method is mandatory in the OGC standard.

Usage
IdentifiedObject$getName()
Returns

Character string with the name of the object.


IdentifiedObject$setAlias()

Set aliases for the object. The aliases are added at the end of the defined aliases.

Usage
IdentifiedObject$setAlias(alias)
Arguments
alias

Character vector with aliases for the object.

Returns

Self, invisibly.


IdentifiedObject$getAlias()

Retrieve the list of aliases for the name of the object. This method is optional in the OGC standard.

Usage
IdentifiedObject$getAlias()
Returns

List of aliases for the name of the object.


IdentifiedObject$setIdentifiers()

Set identifiers for the object. The identifiers are added at the end of the defined identifiers.

Usage
IdentifiedObject$setIdentifiers(id)
Arguments
id

Character vector with identifiers for the object.

Returns

Self, invisibly.


IdentifiedObject$getIdentifiers()

Retrieve the list of identifiers of the object. This method is optional in the OGC standard.

Usage
IdentifiedObject$getIdentifiers()
Returns

List of identifiers for the object.


IdentifiedObject$setRemarks()

Set remarks for the object.

Usage
IdentifiedObject$setRemarks(remarks)
Arguments
remarks

Character string with remarks for the object.

Returns

Self, invisibly.


IdentifiedObject$getRemarks()

Retrieve the remarks of the object. This method is optional in the OGC standard.

Usage
IdentifiedObject$getRemarks()
Returns

Character string with remarks or NA if no remarks have been set.


IdentifiedObject$clone()

The objects of this class are cloneable with this method.

Usage
IdentifiedObject$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.