geozarr_group: GeoZarr Group

geozarr_groupR Documentation

GeoZarr Group

Description

This class implements a GeoZarr group. A GeoZarr group is a group in the hierarchy of a Zarr object having GeoZarr attributes. A GeoZarr group is a container for other groups and arrays.

Super classes

zarr::zarr_object -> zarr::zarr_node -> zarr::zarr_group -> geozarr_group

Methods

Public methods

Inherited methods

geozarr_group$new()

Open a GeoZarr group in a Zarr hierarchy.

Usage
geozarr_group$new(name, metadata, parent, store)
Arguments
name

The name of the group. For a root group, this is the empty string "".

metadata

List with the metadata of the group.

parent

The parent Zarr group instance of this new group, can be missing or NULL for the root group.

store

The zarr_store instance to persist data in.

Returns

An instance of geozarr_group.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.