geozarr_options: GeoZarr package options

View source: R/utils.R

geozarr_optionsR Documentation

GeoZarr package options

Description

Use this function to read or modify package options.

Usage

geozarr_options(key, value)

Arguments

key

Character. A key whose value to modify. If missing, all options are returned.

value

The new value for the option.

Value

A list with all options if argument key is not provided, nothing otherwise.

Examples

geozarr_options()

geozarr documentation built on Sept. 16, 2026, 1:07 a.m.