zarr_conv_proj: GeoZarr "proj" convention

zarr_conv_projR Documentation

GeoZarr "proj" convention

Description

This class implements the GeoZarr "proj" convention. In particular, the following convention is implemented here:

{
  "schema_url": "https://raw.githubusercontent.com/zarr-conventions/geo-proj/refs/tags/v1/schema.json",
  "spec_url": "https://github.com/zarr-conventions/geo-proj/blob/v1/README.md",
  "uuid": "f17cb550-5864-4468-aeb7-f3180cfb622f",
  "name": "proj",
  "description": "Coordinate reference system information for geospatial data"
}

Super class

zarr::zarr_convention -> zarr_conv_proj

Active bindings

code

The "proj:code" attribute, a character string in "authority:code" format identifying a CRS.

wkt2

The "proj:wkt2" attribute, a character string giving a CRS in WKT2 format.

projjson

The "proj:projjson" attribute, a character string giving a CRS in PROJJSON format.

Methods

Public methods

Inherited methods

zarr_conv_proj$new()

Create a new instance of a "proj" convention agent.

Usage
zarr_conv_proj$new(attributes)
Arguments
attributes

Optional, a named list with one or more of the proj attributes. The elements in the list must be one or more of "code", "wkt2" and "projjson".

Returns

A new instance of a "proj" convention agent.


zarr_conv_proj$write()

Write the data of this instance in the attributes of a Zarr object.

Usage
zarr_conv_proj$write(attributes)
Arguments
attributes

A list with Zarr attributes for a group or array. The properties will be written at the root level of attributes.

Returns

The updated attributes.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.