zarr_domain_geozarr: GeoZarr domain object

zarr_domain_geozarrR Documentation

GeoZarr domain object

Description

This class implements a GeoZarr domain object. A GeoZarr domain object is a zarr_domain descendant object identifying groups and arrays in a zarr object that are formatted using GeoZarr conventions.

This domain supports the standard conventions for GeoZarr data sets, specifically the cs and spatial conventions, as well as two other formats for geospatial Zarr data that predate GeoZarr: the format used by the Python XArray library (Zarr v.2 and v.3) and the NCZarr format (Zarr v.2).

Super class

zarr::zarr_domain -> zarr_domain_geozarr

Methods

Public methods


zarr_domain_geozarr$new()

Create a new GeoZarr domain instance. The GeoZarr domain instance manages the groups and arrays in the Zarr store that it refers to. This instance provides access to all objects in the Zarr store.

Usage
zarr_domain_geozarr$new()
Returns

A zar_domain_geozarr object.


zarr_domain_geozarr$build()

This method will create a geozarr_array for an array node and a geozarr_group for a group node with GeoZarr conventions declared in its attributes. Either the "spatial" or "cs" convention has to be declared or the Zarr store has to be formatted using XArray or NCZarr or this domain will decline to manage the node.

Usage
zarr_domain_geozarr$build(name, metadata, parent, store)
Arguments
name

The name of the node.

metadata

List with the metadata of the node.

parent

The parent node of this new node. May be NULL for a root node.

store

The store to persist data in.

Returns

A geozarr_array or geozarr_group instance if supported, FALSE otherwise.


geozarr documentation built on Sept. 16, 2026, 1:07 a.m.