| CoordinateSystem | R Documentation |
This class implements the coordinate system class. This class definition implements the same class from the OGC geoAPI Java package, extended with specific code for this package.
zarr::zarr_object -> IdentifiedObject -> CoordinateSystem
axes(read-only) Retrieve the list of axes that make up this coordinate system.
crsSet or retreive the CRS identifier of the coordinate system.
zarr::zarr_object$append_array_attribute()zarr::zarr_object$attribute()zarr::zarr_object$delete_attribute()zarr::zarr_object$print_attributes()zarr::zarr_object$set_attribute()IdentifiedObject$getAlias()IdentifiedObject$getIdentifiers()IdentifiedObject$getName()IdentifiedObject$getRemarks()IdentifiedObject$setAlias()IdentifiedObject$setIdentifiers()IdentifiedObject$setRemarks()CoordinateSystem$new()Create a new coordinate system. The CS must have at least one axis.
CoordinateSystem$new(name, axes, crs = "", attributes = list())
nameCharacter string. Name of the coordinate system.
axesA list of instances of CoordinateSystemAxis. There must
be at least one axis in the list.
crsOptional, character string with the description of the CRS of this coordinate system, always assumed to be compound.
attributesOptional. A list of attributes of the coordinate
system.
An instance of CoordinateSystem or an error.
CoordinateSystem$print()Print a summary of the coordinate system to the console.
CoordinateSystem$print(...)
...Ignored.
Self, invisibly.
CoordinateSystem$print_axes()Prints details of the axes of the coordinate system to the console. Used internally.
CoordinateSystem$print_axes(...)
...Arguments passed on to data.frame printing.
CoordinateSystem$getDimension()Retrieve the dimension of the coordinate system, the number of axes that make up the coordinate system.
CoordinateSystem$getDimension()
Integer value with the dimension of the coordinate system.
CoordinateSystem$getAxis()Retrieve an axis of the coordinate system by its ordinal number.
CoordinateSystem$getAxis(dimension)
dimensionThe dimension whose axis to retrieve. Note that this is 1-based.
The CoordinateSystemAxis that forms the dimension of the
coordinate system, or an error if the dimension argument in deficient.
CoordinateSystem$clone()The objects of this class are cloneable with this method.
CoordinateSystem$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.