| CoordinateSystemAxis | R Documentation |
This class implements the coordinate system axis class. The axis is always associated with a coordinate system.
In an extension over the OGC standard, an axis can have multiple sets of coordinates. The unit-of-measure is associated with the coordinates and thus not with the axis.
zarr::zarr_object -> IdentifiedObject -> CoordinateSystemAxis
abbreviationSet or retrieve the abbreviation of the axis.
coordinates_list(read-only) Retrieve all coordinates in a list.
coordinates(read-only) Retrieve the currently active coordinates.
length(read-only) Retrieve the length of the axis.
zarr::zarr_object$append_array_attribute()zarr::zarr_object$attribute()zarr::zarr_object$delete_attribute()zarr::zarr_object$print_attributes()zarr::zarr_object$set_attribute()IdentifiedObject$getAlias()IdentifiedObject$getIdentifiers()IdentifiedObject$getName()IdentifiedObject$getRemarks()IdentifiedObject$setAlias()IdentifiedObject$setIdentifiers()IdentifiedObject$setRemarks()CoordinateSystemAxis$new()Create a new axis instance for use in a coordinate system.
CoordinateSystemAxis$new(name, abbreviation, coordinates, attributes = list())
nameCharacter string. Name of the axis.
abbreviationCharacter string. Abbreviation of the axis.
coordinatesA list with one or more named instances of the Coordinates class, or any of its descendants. The first element in the list will be made active.
attributesOptional. A list of attributes of the axis.
An instance of this class or an error.
CoordinateSystemAxis$print()Print a summary of the coordinate system axis to the console.
CoordinateSystemAxis$print(...)
...Ignored.
Self, invisible.
CoordinateSystemAxis$brief()Some details of the axis.
CoordinateSystemAxis$brief()
A 1-row data.frame with some details of the axis.
CoordinateSystemAxis$copy()Return an exact copy of this axis.
CoordinateSystemAxis$copy()
A new instance of CoordinateSystemAxis.
CoordinateSystemAxis$subset()Return an axis spanning a smaller coordinate range. This
method returns an axis which spans the range of indices given by the
rng argument.
CoordinateSystemAxis$subset(name = "", rng = NULL)
nameThe name for the new axis. If an empty string is passed (default), will use the name of this axis.
rngThe range of indices whose values from this axis to include in
the returned axis. If the value of the argument is NULL, return a
copy of the axis.
A new CoordinateSystemAxis instance covering the indicated
range of indices. If the value of the argument rng is NULL, return
a copy of this axis as the new axis.
CoordinateSystemAxis$slice()Given a range of domain coordinate values, returns the indices into this axis that fall within the supplied range. If the axis has bounds, any coordinate whose boundary values fall entirely or partially within the supplied range will be included in the result.
CoordinateSystemAxis$slice(rng)
rngA numeric vector whose extreme values indicate the indices of coordinates to return.
An integer vector of length 2 with the lower and higher indices
into the axis that fall within the range of coordinates in argument
rng. Returns NULL if no (boundary) values of the axis fall within
the range of coordinates.
CoordinateSystemAxis$getAbbreviation()Retrieve the abbreviation of the axis. This method is mandatory in the OGC standard.
CoordinateSystemAxis$getAbbreviation()
Character string with the abbreviation of the axis.
CoordinateSystemAxis$getDirection()Retrieve the direction of the axis. This method is mandatory in the OGC standard.
CoordinateSystemAxis$getDirection()
Character string with the direction of the axis.
CoordinateSystemAxis$getUnit()Retrieve the unit of measure of the axis. This method is mandatory in the OGC standard.
CoordinateSystemAxis$getUnit()
Character string with the unit of measure of the axis.
CoordinateSystemAxis$getMinimumValue()Retrieve the minimum coordinate value of this axis, in units of the unit of measure of the axis.
CoordinateSystemAxis$getMinimumValue()
Negative infinity.
CoordinateSystemAxis$getMaximumValue()Retrieve the maximum coordinate value of this axis, in units of the unit of measure of the axis.
CoordinateSystemAxis$getMaximumValue()
Positive infinity.
CoordinateSystemAxis$getRangeMeaning()Retrieve the minimum coordinate value of this axis, in units of the unit of measure of the axis.
CoordinateSystemAxis$getRangeMeaning()
The character string 'EXACT'.
CoordinateSystemAxis$clone()The objects of this class are cloneable with this method.
CoordinateSystemAxis$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.