| Coordinates | R Documentation |
This class implements the coordinates class. The coordinates are always associated with a coordinate system axis.
This class provides the basic interface for coordinate values and it manages numeric coordinate values, both integer and floating-point. Descendant classes manage packed numerical values, character values and time values.
The optional boundary values for numeric coordinate values that define the finite extent of each element in the coordinates are also managed by this class.
zarr::zarr_object -> Coordinates
nameSet or retrieve the name of the coordinate set.
directionSet or retrieve the direction of the coordinates.
values(read-only) Retrieve the coordinate values as a full vector of values.
raw(read-only) Retrieve the coordinate values as stored, either a full vector or packed.
boundsSet or retrieve the boundary values around coordinates.
When setting, assign a matrix with 2 rows and as many columns as there
are coordinates values. When retrieving, a matrix as just described or
NULL if boundary values have not been set.
bounds_raw(read-only) Retrieve the boundary values around
coordinates exactly as they are stored with the coordinate. If the
boundary values are packed, a vector of length 2 is returned, otherwise
a matrix with 2 rows and as many columns as there are coordinates
values or NULL if boundary values have not been set.
range(read-only) Retrieve the extreme values of the coordinates.
length(read-only) The number of elements in this instance once the values are unpacked.
unitCharacter string giving the unit-of-measure of the coordinate values.
attributes(read-only) A named list with the attributes of this
object.
Coordinates$new()Create a new coordinates instance for use with a coordinate system axis.
Coordinates$new( name, direction, unit, values, bounds = NULL, attributes = list() )
nameCharacter string. Name of the coordinate set.
directionCharacter string. Direction of the coordinates. Must be
one from the set of values given in AxisDirection.
unitCharacter string. Unit of measure of the coordinates.
valuesA vector of values.
boundsOptional. If the boundaries are regularly spaced, a vector with the offset to the boundary lower and higher than the coordinate value, respectively. Otherwise, a matrix with two rows and as many columns as there are elements, with the offset to the boundary below the coordinate value in row 1 and the offset to the boundary above the coordinate value in row 2. The boundaries represent the finite extent around the boundary value that this value is representative for. If this argument is not provided, the coordinate values are assumed to represent a point value.
attributesOptional. A list of attributes of the coordinates.
An instance of this class or an error.
Coordinates$print()Print a summary of the coordinates to the console.
Coordinates$print(...)
...Ignored.
Self, invisible.
Coordinates$brief()Some details of the axis.
Coordinates$brief()
A 1-row data.frame with some details of the axis.
Coordinates$copy()Return an exact copy of these coordinates.
Coordinates$copy()
A new instance of Coordinates.
Coordinates$subset()Return coordinates spanning a smaller coordinate range.
Coordinates$subset(rng)
rngThe range of indices to include in the returned coordinates.
A new Coordinates instance covering the indicated range of
indices, including boundary values, present.
Coordinates$slice()Given a range of domain coordinate values, returns the indices into the axis that fall within the supplied range. If the axis has boundary values, any coordinate whose boundary values fall entirely or partially within the supplied range will be included in the result.
Coordinates$slice(rng)
rngA numeric vector whose extreme values indicate the indices of coordinates to return.
An integer vector of length 2 with the lower and higher indices
into the axis that fall within the range of coordinates in argument
rng. Returns NULL if no (boundary) values of the axis fall within
the range of coordinates.
Coordinates$getDirection()Retrieve the direction of the coordinates. This method is mandatory in the OGC standard for an axis.
Coordinates$getDirection()
Character string with the direction of the coordinates.
Coordinates$getUnit()Retrieve the unit of measure of the coordinates. This method is mandatory in the OGC standard for an axis.
Coordinates$getUnit()
Character string with the unit of measure of the axis.
Coordinates$getMinimumValue()Retrieve the minimum coordinate value of this set of coordinates, in units of the unit of measure of the coordinates.
Coordinates$getMinimumValue()
Negative infinity.
Coordinates$getMaximumValue()Retrieve the maximum coordinate value of this set of coordinates, in units of the unit of measure of the coordinates.
Coordinates$getMaximumValue()
Positive infinity.
Coordinates$getRangeMeaning()Retrieve the interpretation of coordinate values, either as a direct value ("EXACT") or as a wrap-around value between the minimum and maximum value of the coordinates ("WRAPAROUND").
Coordinates$getRangeMeaning()
The character string 'EXACT'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.