| CoordinatesOrdinal | R Documentation |
This class implements ordinal values. Ordinal values are typically assigned to axes that have no other coordinates assigned to them. By default, ordinal values start at 0 (as per the Zarr specification) but after subsetting or other forms of selection the value may be different.
zarr::zarr_object -> Coordinates -> CoordinatesPacked -> CoordinatesOrdinal
zarr::zarr_object$append_array_attribute()zarr::zarr_object$attribute()zarr::zarr_object$delete_attribute()zarr::zarr_object$print_attributes()zarr::zarr_object$set_attribute()Coordinates$brief()Coordinates$getDirection()Coordinates$getMaximumValue()Coordinates$getMinimumValue()Coordinates$getRangeMeaning()Coordinates$getUnit()Coordinates$print()Coordinates$slice()CoordinatesOrdinal$new()Create an instance of this class.
CoordinatesOrdinal$new(name, direction, length, low = 0L, attributes = list())
nameCharacter string. Name of the coordinate set.
directionCharacter string. Direction of the coordinates. Must be one from a set of values.
lengthInteger value giving the number of elements in this instance.
lowOptional. Integer value giving the lowest index value in this instance. When omitted, defaults to 0L.
attributesOptional. A list of attributes of the coordinates.
An instance of this class.
CoordinatesOrdinal$copy()Return an exact copy of these coordinates.
CoordinatesOrdinal$copy()
A new instance of CoordinatesOrdinal.
CoordinatesOrdinal$subset()Return a subset of the coordinate values.
CoordinatesOrdinal$subset(rng)
rngThe range of indices whose values from these coordinate values to include in the result.
A new CoordinatesOrdinal instance covering the indicated
range of values.
CoordinatesOrdinal$clone()The objects of this class are cloneable with this method.
CoordinatesOrdinal$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.