| CoordinatesPacked | R Documentation |
This class implements the packed coordinates class. The coordinates are always associated with a coordinate system axis.
This class provides the specific interface for packed numeric coordinate values, both integer and floating-point.
zarr::zarr_object -> Coordinates -> CoordinatesPacked
values(read-only) Retrieve the unpacked coordinate values.
range(read-only) Retrieve the extreme values of the coordinates.
zarr::zarr_object$append_array_attribute()zarr::zarr_object$attribute()zarr::zarr_object$delete_attribute()zarr::zarr_object$print_attributes()zarr::zarr_object$set_attribute()Coordinates$brief()Coordinates$getDirection()Coordinates$getMaximumValue()Coordinates$getMinimumValue()Coordinates$getRangeMeaning()Coordinates$getUnit()Coordinates$print()Coordinates$slice()CoordinatesPacked$new()Create a new coordinates instance for use with a coordinate system axis for regularly spaced coordinate values.
CoordinatesPacked$new( name, direction, unit, values, length, bounds = NULL, attributes = list() )
nameCharacter string. Name of the coordinate set.
directionCharacter string. Direction of the coordinates. Must be one from a set of values.
unitCharacter string. Unit of measure of the coordinates.
valuesA vector of values. There must be two values: the initial coordinate value and the increment.
lengthInteger value giving the number of coordinates that this packed data is for.
boundsOptional. If the boundaries are regularly spaced, a vector with the offset to the boundary lower and higher than the coordinate value, respectively. Otherwise, a matrix with two rows and as many columns as there are elements, with the offset to the boundary below the coordinate value in row 1 and the offset to the boundary above the coordinate value in row 2. The boundaries represent the finite extent around the boundary value that this value is representative for. If this argument is not provided, the coordinate values are assumed to represent a point value.
attributesOptional. A list of attributes of the coordinates.
An instance of this class or an error.
CoordinatesPacked$copy()Return an exact copy of these coordinates.
CoordinatesPacked$copy()
A new instance of CoordinatesPacked.
CoordinatesPacked$subset()Return coordinates spanning a smaller coordinate range.
CoordinatesPacked$subset(rng)
rngThe range of indices to include in the returned coordinates.
A new CoordinatesPacked instance covering the indicated range of
indices, including boundary values, present.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.