| CoordinatesString | R Documentation |
This class implements the string-type coordinates class. The coordinates are always associated with a coordinate system axis.
This class provides the specific interface for string-type coordinate values.
zarr::zarr_object -> Coordinates -> CoordinatesString
zarr::zarr_object$append_array_attribute()zarr::zarr_object$attribute()zarr::zarr_object$delete_attribute()zarr::zarr_object$print_attributes()zarr::zarr_object$set_attribute()Coordinates$brief()Coordinates$getDirection()Coordinates$getMaximumValue()Coordinates$getMinimumValue()Coordinates$getRangeMeaning()Coordinates$getUnit()Coordinates$print()Coordinates$slice()CoordinatesString$new()Create a new coordinates instance for use with a coordinate system axis for string-type coordinate values.
CoordinatesString$new(name, direction, unit, values, attributes = list())
nameCharacter string. Name of the coordinate set.
directionCharacter string. Direction of the coordinates. Must be one from a set of values.
unitCharacter string. Unit of measure of the coordinates.
valuesA vector of values. There must be two values: the initial coordinate value and the increment.
attributesOptional. A list of attributes of the coordinates.
An instance of this class or an error.
CoordinatesString$copy()Return an exact copy of these coordinates.
CoordinatesString$copy()
A new instance of CoordinatesString.
CoordinatesString$subset()Return coordinates spanning a smaller coordinate range.
CoordinatesString$subset(rng)
rngThe range of indices to include in the returned coordinates.
A new CoordinatesString instance covering the indicated range of
indices.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.