| IdentifiedObject | R Documentation |
This class definition implements the same class from the OGC geoAPI Java package, extended with specific code for this package. This class is ancestor to many other, more useful classes. This class just provides basic identification properties. It is not very useful to instantiate this class directly; instead, use descendant classes.
zarr::zarr_object -> IdentifiedObject
name(read-only) The name of the object.
attributes(read-only) A named list with the attributes of this
object.
IdentifiedObject$new()Create a new object.
IdentifiedObject$new(name, attributes = list())
nameCharacter string. Name of the object.
attributesOptional. A list of attributes of the object.
A new instance of the object, or an error if the object could not be created.
IdentifiedObject$getName()Retrieve the name of the object. This method is mandatory in the OGC standard.
IdentifiedObject$getName()
Character string with the name of the object.
IdentifiedObject$setAlias()Set aliases for the object. The aliases are added at the end of the defined aliases.
IdentifiedObject$setAlias(alias)
aliasCharacter vector with aliases for the object.
Self, invisibly.
IdentifiedObject$getAlias()Retrieve the list of aliases for the name of the object. This method is optional in the OGC standard.
IdentifiedObject$getAlias()
List of aliases for the name of the object.
IdentifiedObject$setIdentifiers()Set identifiers for the object. The identifiers are added at the end of the defined identifiers.
IdentifiedObject$setIdentifiers(id)
idCharacter vector with identifiers for the object.
Self, invisibly.
IdentifiedObject$getIdentifiers()Retrieve the list of identifiers of the object. This method is optional in the OGC standard.
IdentifiedObject$getIdentifiers()
List of identifiers for the object.
IdentifiedObject$setRemarks()Set remarks for the object.
IdentifiedObject$setRemarks(remarks)
remarksCharacter string with remarks for the object.
Self, invisibly.
IdentifiedObject$getRemarks()Retrieve the remarks of the object. This method is optional in the OGC standard.
IdentifiedObject$getRemarks()
Character string with remarks or NA if no remarks have been
set.
IdentifiedObject$clone()The objects of this class are cloneable with this method.
IdentifiedObject$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.