| geozarr_group | R Documentation |
This class implements a GeoZarr group. A GeoZarr group is a group in the hierarchy of a Zarr object having GeoZarr attributes. A GeoZarr group is a container for other groups and arrays.
zarr::zarr_object -> zarr::zarr_node -> zarr::zarr_group -> geozarr_group
zarr::zarr_object$print_attributes()zarr::zarr_node$absolute_path()zarr::zarr_node$append_array_attribute()zarr::zarr_node$attribute()zarr::zarr_node$delete_attribute()zarr::zarr_node$relative_path()zarr::zarr_node$save()zarr::zarr_node$set_attribute()zarr::zarr_node$walk_path()zarr::zarr_group$add_array()zarr::zarr_group$add_group()zarr::zarr_group$build_hierarchy()zarr::zarr_group$count_arrays()zarr::zarr_group$delete()zarr::zarr_group$delete_all()zarr::zarr_group$get_node()zarr::zarr_group$hierarchy()zarr::zarr_group$hierarchy_nodes()zarr::zarr_group$post_open()zarr::zarr_group$print()zarr::zarr_group$set_node()geozarr_group$new()Open a GeoZarr group in a Zarr hierarchy.
geozarr_group$new(name, metadata, parent, store)
nameThe name of the group. For a root group, this is the empty
string "".
metadataList with the metadata of the group.
parentThe parent Zarr group instance of this new group, can be
missing or NULL for the root group.
storeThe zarr_store instance to persist data in.
An instance of geozarr_group.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.