| geozarr_options | R Documentation |
Use this function to read or modify package options.
geozarr_options(key, value)
key |
Character. A key whose value to modify. If missing, all options are returned. |
value |
The new value for the option. |
A list with all options if argument key is not provided,
nothing otherwise.
geozarr_options()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.