| zarr_conv_proj | R Documentation |
This class implements the GeoZarr "proj" convention. In particular, the following convention is implemented here:
{
"schema_url": "https://raw.githubusercontent.com/zarr-conventions/geo-proj/refs/tags/v1/schema.json",
"spec_url": "https://github.com/zarr-conventions/geo-proj/blob/v1/README.md",
"uuid": "f17cb550-5864-4468-aeb7-f3180cfb622f",
"name": "proj",
"description": "Coordinate reference system information for geospatial data"
}
zarr::zarr_convention -> zarr_conv_proj
codeThe "proj:code" attribute, a character string in "authority:code" format identifying a CRS.
wkt2The "proj:wkt2" attribute, a character string giving a CRS in WKT2 format.
projjsonThe "proj:projjson" attribute, a character string giving a CRS in PROJJSON format.
zarr_conv_proj$new()Create a new instance of a "proj" convention agent.
zarr_conv_proj$new(attributes)
attributesOptional, a named list with one or more of the proj
attributes. The elements in the list must be one or more of "code",
"wkt2" and "projjson".
A new instance of a "proj" convention agent.
zarr_conv_proj$write()Write the data of this instance in the attributes of a Zarr object.
zarr_conv_proj$write(attributes)
attributesA list with Zarr attributes for a group or array. The
properties will be written at the root level of attributes.
The updated attributes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.