| zarr_domain_geozarr | R Documentation |
This class implements a GeoZarr domain object. A GeoZarr domain
object is a zarr_domain descendant object identifying groups and arrays
in a zarr object that are formatted using GeoZarr conventions.
This domain supports the standard conventions for GeoZarr data sets,
specifically the cs and spatial conventions, as well as two other
formats for geospatial Zarr data that predate GeoZarr: the format used by
the Python XArray library (Zarr v.2 and v.3) and the NCZarr format (Zarr
v.2).
zarr::zarr_domain -> zarr_domain_geozarr
zarr_domain_geozarr$new()Create a new GeoZarr domain instance. The GeoZarr domain instance manages the groups and arrays in the Zarr store that it refers to. This instance provides access to all objects in the Zarr store.
zarr_domain_geozarr$new()
A zar_domain_geozarr object.
zarr_domain_geozarr$build()This method will create a geozarr_array for an array node
and a geozarr_group for a group node with GeoZarr conventions
declared in its attributes. Either the "spatial" or "cs" convention
has to be declared or the Zarr store has to be formatted using XArray
or NCZarr or this domain will decline to manage the node.
zarr_domain_geozarr$build(name, metadata, parent, store)
nameThe name of the node.
metadataList with the metadata of the node.
parentThe parent node of this new node. May be NULL for a root
node.
storeThe store to persist data in.
A geozarr_array or geozarr_group instance if supported,
FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.